@@ -11,7 +11,7 @@ use base qw( IO::Async::Listener );
 
 use Carp;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 use Net::Async::WebSocket::Protocol;
 
@@ -25,11 +25,11 @@ C<Net::Async::WebSocket::Server> - serve WebSocket clients using C<IO::Async>
 
  use IO::Async::Loop;
  use Net::Async::WebSocket::Server;
- 
+
  my $server = Net::Async::WebSocket::Server->new(
     on_client => sub {
        my ( undef, $client ) = @_;
- 
+
        $client->configure(
           on_frame => sub {
              my ( $self, $frame ) = @_;
@@ -38,18 +38,15 @@ C<Net::Async::WebSocket::Server> - serve WebSocket clients using C<IO::Async>
        );
     }
  );
- 
+
  my $loop = IO::Async::Loop->new;
  $loop->add( $server );
- 
+
  $server->listen(
     service => 3000,
- 
-    on_listen_error => sub { die "Cannot listen - $_[-1]" },
-    on_resolve_error => sub { die "Cannot resolve - $_[-1]" },
- );
- 
- $loop->loop_forever;
+ )->get;
+
+ $loop->run;
 
 =head1 DESCRIPTION
 
@@ -65,44 +62,47 @@ sub new
    return $class->SUPER::new(
       @_,
       handle_class => "Net::Async::WebSocket::Protocol",
-      on_accept => sub {
-         my ( $self, $client ) = @_;
+   );
+}
 
-         my $hs = Protocol::WebSocket::Handshake::Server->new;
+sub on_accept
+{
+   my $self = shift;
+   my ( $client ) = @_;
 
-         $client->configure(
-            on_read => sub {
-               my ( $client, $buffref, $closed ) = @_;
+   my $hs = Protocol::WebSocket::Handshake::Server->new;
 
-               $hs->parse( $$buffref ); # modifies $$buffref
+   $client->configure(
+      on_read => sub {
+         my ( $client, $buffref, $closed ) = @_;
 
-               if( $hs->is_done ) {
-                  my $on_handshake = $self->can_event( "on_handshake" ) ||
-                     sub { $_[3]->( 1 ) };
+         $hs->parse( $$buffref ); # modifies $$buffref
 
-                  $on_handshake->( $self, $client, $hs, sub {
-                     my ( $ok ) = @_;
+         if( $hs->is_done ) {
+            my $on_handshake = $self->can_event( "on_handshake" ) ||
+               sub { $_[3]->( 1 ) };
 
-                     unless( $ok ) {
-                        $self->remove_child( $client );
-                        return;
-                     }
+            $on_handshake->( $self, $client, $hs, sub {
+               my ( $ok ) = @_;
 
-                     $client->configure( on_read => undef );
-                     $client->write( $hs->to_string );
-
-                     $client->debug_printf( "HANDSHAKE done" );
-                     $self->invoke_event( on_client => $client );
-                  } );
+               unless( $ok ) {
+                  $self->remove_child( $client );
+                  return;
                }
 
-               return 0;
-            },
-         );
+               $client->configure( on_read => undef );
+               $client->write( $hs->to_string );
 
-         $self->add_child( $client );
+               $client->debug_printf( "HANDSHAKE done" );
+               $self->invoke_event( on_client => $client );
+            } );
+         }
+
+         return 0;
       },
    );
+
+   $self->add_child( $client );
 }
 
 =head1 PARAMETERS
